@@ -12,32 +12,33 @@
 #
 ##############################################################################
 
-from zope.interface import implements
+from zope.interface import implementer
 
 from martian import util
 from martian.error import GrokError
 from martian.interfaces import IGrokker, IComponentGrokker
 from martian.martiandirective import directive, component
 
+
+@implementer(IGrokker)
 class GrokkerBase(object):
-    implements(IGrokker)
-   
+
     def grok(self, name, obj, **kw):
         raise NotImplementedError
 
-    
+
 class GlobalGrokker(GrokkerBase):
     """Grokker that groks once per module.
     """
 
     def grok(self, name, obj, **kw):
         raise NotImplementedError
-    
 
+
+@implementer(IComponentGrokker)
 class ClassGrokker(GrokkerBase):
     """Grokker that groks classes in a module.
     """
-    implements(IComponentGrokker)
 
     def grok(self, name, class_, module_info=None, **kw):
         module = None
@@ -93,14 +94,13 @@ class MethodGrokker(ClassGrokker):
         raise NotImplementedError
 
 
+@implementer(IComponentGrokker)
 class InstanceGrokker(GrokkerBase):
     """Grokker that groks instances in a module.
     """
-    implements(IComponentGrokker)
 
-    def grok(self, name, class_, **kw):        
+    def grok(self, name, class_, **kw):
         return self.execute(class_, **kw)
 
     def execute(self, class_, **kw):
         raise NotImplementedError
-
