@@ -7,8 +7,11 @@ from zope.interface.interface import TAGGED_DATA
 from martian import util
 from martian.error import GrokImportError, GrokError
 from martian import scan
+from martian import compat3
 
 UNKNOWN = object()
+_unused = object()
+
 
 class StoreOnce(object):
 
@@ -25,15 +28,19 @@ class StoreOnce(object):
     def setattr(self, context, directive, value):
         setattr(context, directive.dotted_name(), value)
 
+
 ONCE = StoreOnce()
 
+
 class StoreOnceGetFromThisClassOnly(StoreOnce):
 
     def get(self, directive, component, default):
         return component.__dict__.get(directive.dotted_name(), default)
 
+
 ONCE_NOBASE = StoreOnceGetFromThisClassOnly()
 
+
 class StoreMultipleTimes(StoreOnce):
 
     def get(self, directive, component, default):
@@ -58,15 +65,19 @@ class StoreMultipleTimes(StoreOnce):
         values = locals_.setdefault(directive.dotted_name(), [])
         values.append(value)
 
+
 MULTIPLE = StoreMultipleTimes()
 
+
 class StoreMultipleTimesNoBase(StoreMultipleTimes):
 
     def get(self, directive, component, default):
         return component.__dict__.get(directive.dotted_name(), default)
 
+
 MULTIPLE_NOBASE = StoreMultipleTimesNoBase()
 
+
 class StoreDict(StoreOnce):
 
     def get(self, directive, component, default):
@@ -93,8 +104,10 @@ class StoreDict(StoreOnce):
                 "key-value pair." % directive.name)
         values_dict[key] = value
 
+
 DICT = StoreDict()
 
+
 class TaggedValueStoreOnce(StoreOnce):
     """Stores the directive value in a interface tagged value.
     """
@@ -118,15 +131,18 @@ class TaggedValueStoreOnce(StoreOnce):
     def setattr(self, context, directive, value):
         context.setTaggedValue(directive.dotted_name(), value)
 
+
 # for now, use scope = martian.CLASS to create directives that can
 # work on interfaces (or martian.CLASS_OR_MODULE)
 ONCE_IFACE = TaggedValueStoreOnce()
 
 _USE_DEFAULT = object()
 
+
 class UnknownError(GrokError):
     pass
 
+
 def _default(mro, get_default):
     """Apply default rule to list of classes in mro.
     """
@@ -137,7 +153,7 @@ def _default(mro, get_default):
             if util.is_baseclass(base):
                 break
             result = get_default(base, module_of_base)
-        except UnknownError, e:
+        except UnknownError as e:
             # store error if this is the first UnknownError we ran into
             if error is None:
                 error = e
@@ -147,9 +163,10 @@ def _default(mro, get_default):
     # if we haven't found a result, raise the first error we had as
     # a GrokError
     if error is not None:
-        raise GrokError(unicode(error), error.component)
+        raise GrokError(compat3.str(error), error.component)
     return UNKNOWN
 
+
 class ClassScope(object):
     description = 'class'
 
@@ -165,8 +182,10 @@ class ClassScope(object):
             component = component.__class__
         return _default(inspect.getmro(component), get_default)
 
+
 CLASS = ClassScope()
 
+
 class ClassOrModuleScope(object):
     description = 'class or module'
 
@@ -197,8 +216,10 @@ class ClassOrModuleScope(object):
         # look up default rule for this class or its bases
         return _default(mro, get_default)
 
+
 CLASS_OR_MODULE = ClassOrModuleScope()
 
+
 class ModuleScope(object):
     description = 'module'
 
@@ -211,9 +232,9 @@ class ModuleScope(object):
             return result
         return get_default(component, component)
 
+
 MODULE = ModuleScope()
 
-_unused = object()
 
 class Directive(object):
 
@@ -225,9 +246,9 @@ class Directive(object):
 
         self.frame = frame = sys._getframe(1)
         if not self.scope.check(frame):
-            raise GrokImportError("The '%s' directive can only be used on "
-                                  "%s level." %
-                                  (self.name, self.scope.description))
+            raise GrokImportError(
+                "The '%s' directive can only be used on %s level." %
+                (self.name, self.scope.description))
 
         self.check_factory_signature(*args, **kw)
 
@@ -236,18 +257,22 @@ class Directive(object):
             validate(*args, **kw)
 
         value = self.factory(*args, **kw)
-
         self.store.set(frame.f_locals, self, value)
 
     # To get a correct error message, we construct a function that has
     # the same signature as factory(), but without "self".
     def check_factory_signature(self, *arguments, **kw):
-        args, varargs, varkw, defaults = inspect.getargspec(self.factory)
+        if sys.version_info.major == 2:
+            (args, varargs, varkw, defaults) = inspect.getargspec(self.factory)
+        else:
+            (args, varargs, varkw, defaults,
+             _, __, ___) = inspect.getfullargspec(self.factory)
         argspec = inspect.formatargspec(args[1:], varargs, varkw, defaults)
-        exec("def signature_checker" + argspec + ": pass")
+        ns = dict()
+        exec("def signature_checker" + argspec + ": pass", dict(), ns)
         try:
-            signature_checker(*arguments, **kw)
-        except TypeError, e:
+            ns['signature_checker'](*arguments, **kw)
+        except TypeError as e:
             message = e.args[0]
             message = message.replace("signature_checker()", self.name)
             raise TypeError(message)
@@ -267,9 +292,11 @@ class Directive(object):
     def bind(cls, default=_unused, get_default=None, name=None):
         return BoundDirective(cls, default, get_default, name)
 
+
 class BoundDirective(object):
 
-    def __init__(self, directive, default=_unused, get_default=None, name=None):
+    def __init__(
+            self, directive, default=_unused, get_default=None, name=None):
         self.directive = directive
         self.default = default
         if name is None:
@@ -292,15 +319,19 @@ class BoundDirective(object):
 
     def get(self, component=None, module=None, **data):
         directive = self.directive
+
         def get_default(component, module):
             return self.get_default(component, module, **data)
-        return directive.scope.get(directive, component,
-                                   get_default=get_default)
+
+        return directive.scope.get(
+            directive, component, get_default=get_default)
+
 
 class MultipleTimesDirective(Directive):
     store = MULTIPLE
     default = []
 
+
 class MarkerDirective(Directive):
     store = ONCE
     default = False
@@ -308,21 +339,25 @@ class MarkerDirective(Directive):
     def factory(self):
         return True
 
+
 def validateText(directive, value):
     if util.not_unicode_or_ascii(value):
         raise GrokImportError("The '%s' directive can only be called with "
                               "unicode or ASCII." % directive.name)
 
+
 def validateInterfaceOrClass(directive, value):
     if not (IInterface.providedBy(value) or util.isclass(value)):
         raise GrokImportError("The '%s' directive can only be called with "
                               "a class or an interface." % directive.name)
 
+
 def validateClass(directive, value):
     if not util.isclass(value):
         raise GrokImportError("The '%s' directive can only be called with "
                               "a class." % directive.name)
 
+
 def validateInterface(directive, value):
     if not (IInterface.providedBy(value)):
         raise GrokImportError("The '%s' directive can only be called with "
@@ -335,4 +370,4 @@ def validateInterface(directive, value):
 # in the fake module being tested and not in the FakeModule base class;
 # the system cannot find it on the frame if it is in the base class.
 def is_fake_module(frame):
-    return frame.f_locals.has_key('fake_module')
+    return 'fake_module' in frame.f_locals
