@@ -1,20 +1,24 @@
 # this is a module has a single Context subclass in it.
 # this module is used in a scan_for_context.txt test.
 
-import os
+from zope.interface import implementer
 from martian.tests.scanforclasses import IContext
-from zope.interface import implements
 
 foo = "Bar"
 
+
 class Qux(object):
     pass
 
+
 class Hallo:
     pass
 
+
+@implementer(IContext)
 class MyContext(object):
-    implements(IContext)
+    pass
+
 
 qux = Qux()
 hallo = Hallo()
