@@ -1,10 +1,13 @@
-import animal
+from martian.tests.testpackage import animal
+
 
 class Whale(animal.Animal):
     pass
 
+
 class Dragon(animal.Animal):
     pass
 
+
 class SpermWhale(Whale):
     pass
