@@ -1,6 +1,6 @@
 
 def main():
-    print "Hello"
+    print("Hello")
+
 
 main()
-
